<?php
define( 'THISPATH', dirname(__FILE__) . '/' );
define( 'ROOTPATH', dirname(THISPATH) );
define( 'CACHPATH', THISPATH.'cache/' );

function set_404() {
	global $is_404;
	header( "HTTP/1.0 404 Not Found", true, 404 );
	$is_404 = true;
	echo <<<EOT
<!DOCTYPE html>
<html>
<head><title>404 Not Found</title></head>
<body>
<h1>Not Found</h1>
<p>The requested URL was not found on this server.</p>
</body></html>
EOT;
	exit;
}

function set_header( $ctype ) {
	@header( "Content-type: $ctype" );
	@header( 'Cache-Control: no-cache' );
	@header( 'Cache-Control: max-age=0', false ); 
	@header( 'Expires:'.gmdate('D, d M Y H:i:s', 0 ).' GMT' );
}

function proc_imagick( $img, $text, $cache=false ) {
	global $img_size;
	
	$image = new Imagick( $img );
	$w = $image->getImageWidth();
	$h = $image->getImageHeight();
	$fs = $w/24;
	if( $h > $w )
		$bl = $h/128;
	else
		$bl = $w/128;
	if( $bl<4 )
		$bl = 4;
		
	$image->blurImage( $bl, $bl );
	$draw = new ImagickDraw();
	$draw->setGravity( Imagick::GRAVITY_CENTER );
	$draw->setFontFamily( "Times" );
	$draw->setFontSize( $fs );
	$draw->setFillColor('black');
	$draw->setTextUnderColor( '#ffffff55' );
	$image->annotateImage( $draw, 0, 0, 0, $text );
	if( $cache )
		$image->writeImage( $cache );

	set_header( $img_size['mime'] );
	echo $image;
	exit;
}

function proc_gd( $img, $text, $cache=false ) {
	global $img_size;
	
	switch( $img_size["mime"] ){
		case "image/jpeg":
			$image = ImageCreateFromJpeg( $img );
		break;
		case "image/png":
			$image = ImageCreateFromPng( $img );
		break;
		default:
			$image = false;
		break;
	}
	
	if( $image ) {
		$w = $img_size[0];
		$h = $img_size[1];
		$fs = $w/24;
		if( $h > $w )
			$bl = $h/100;
		else
			$bl = $w/100;
		if( $bl<4 )
			$bl = 4;
		ImageFilter( $image, IMG_FILTER_PIXELATE, $bl );
		
		$font = THISPATH.'font.ttf';
		$t_color = ImageColorAllocate( $image, 0, 0, 0 );
		$b_color = ImageColorAllocateAlpha ( $image, 255, 255, 255, 48 );
		
		$t_box = ImageTtfBbox( $fs, 0, $font, $text );
		$t_width = abs( $t_box[4] - $t_box[0] );
		$t_height = abs( $t_box[5] - $t_box[1] );

		$t_x = ($w-$t_width)/2;
		$t_y = ($h+$t_height)/2;
		
		ImageFilledRectangle( $image, $t_x, $t_y-$t_height, $t_x+$t_width, $t_y+$t_height/2, $b_color );
		ImageTtfText( $image, $fs, 0, $t_x, $t_y, $t_color, $font, $text );
		
		if( $cache ) {
			switch( $img_size["mime"] ){
				case "image/jpeg":
					ImageJpeg( $image, $cache );
				break;
				case "image/png":
					ImagePng( $image, $cache );
				break;
			}
		}
		set_header( $img_size['mime'] );
		switch( $img_size["mime"] ){
			case "image/jpeg":
				ImageJpeg( $image );
			break;
			case "image/png":
				ImagePng( $image );
			break;
		}
	}
	else
		set_404();
	
	exit;
}

$img_uri = urldecode( $_SERVER['REQUEST_URI'] );
$img_ext = pathinfo( $img_uri, PATHINFO_EXTENSION );
$img_org_file = ROOTPATH.$img_uri;
$img_file = $img_org_file;
$img_text = ' Das scharfe Bild bei putzlowitsch.de ';


if( file_exists( $img_file ) ) {
	$img_size = getimagesize( $img_file );
	if( $img_size ) {
		$img_uri_hash = md5( $img_uri );
		$img_cache_file = CACHPATH."test_$img_uri_hash.$img_ext";
		if( file_exists( $img_cache_file ) ) {
			$img_file = $img_cache_file;
			if( $img_size ) {
				set_header( $img_size['mime'] );
				@readfile( $img_file );
				exit;
			}
			else
				set_404();
		}	
		else {
			proc_gd( $img_org_file, $img_text, $img_cache_file );
		}
	}
	else
		set_404();
}
else
	set_404();
?>